@@ -1,25 +1,22 @@
+#' Internal function to check if the MCMC's tracelog file can be created.
+#'
 #' Check if the MCMC's tracelog file can be created.
 #' Will \link{stop} if not.
-#' If the file already exists, it is assumed that a new file can be created
+#' If the tracelog file already exists,
+#' it is assumed that a new file can be created,
+#' by overwriting the existing one.
 #' @inheritParams default_params_doc
+#' @return Nothing.
+#' Will \link{stop} if the MCMC's tracelog file is absent and cannot be created.
+#' @author Richèl J.C. Bilderbeek
 #' @export
 check_can_create_tracelog_file <- function(
   beast2_options
 ) {
-  # Extract the tracelog file
   testthat::expect_true(file.exists(beast2_options$input_filename))
-  text <- readr::read_lines(beast2_options$input_filename)
-  tracelog_line <- stringr::str_subset(
-    string = text,
-    pattern = "<logger id=\"tracelog\""
+  tracelog_filename <- beastier::extract_tracelog_filename_from_beast2_input_file( # nolint indeed a long internal function name
+    input_filename = beast2_options$input_filename
   )
-  testthat::expect_equal(length(tracelog_line), 1)
-  matches <- stringr::str_match(
-    string = tracelog_line,
-    pattern = "fileName=\\\"([:graph:]+)\\\" "
-  )
-  testthat::expect_equal(ncol(matches), 2)
-  tracelog_filename <- matches[1, 2]
 
   if (file.exists(tracelog_filename)) {
      file.remove(tracelog_filename)
