@@ -1,5 +1,7 @@
 #' Continue a BEAST2 run
 #' @inheritParams default_params_doc
+#' @return The text sent to \code{STDOUT} and \code{STDERR}.
+#'   It will create the file with name \code{output_state_filenames}
 #' @examples
 #' if (is_beast2_installed() && is_on_ci()) {
 #'   beast2_options <- create_beast2_options(
@@ -85,7 +87,7 @@ continue_beast2 <- function(
   testthat::expect_true(
     file.exists(beast2_options$output_state_filename),
     info = paste0(
-      "BEAST2 state file not created. \n",
+      "BEAST2 state file not created after a continued run. \n",
       "Command '", paste0(cmd, collapse = " "), "' failed. ",
       "'beast2_options$output_state_filename': '",
         beast2_options$output_state_filename, "'\n",
