@@ -10,6 +10,7 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 get_default_beast2_jar_path <- function(
+  beast2_folder = beastier::get_default_beast2_folder(),
   os = rappdirs::app_dir()$os
 ) {
   beastier::check_os(os)
@@ -26,7 +27,7 @@ get_default_beast2_jar_path <- function(
 
   normalizePath(
     file.path(
-      rappdirs::user_data_dir(),
+      beast2_folder,
       beast_foldername,
       "lib",
       launcher_name
